@@ -670,6 +670,7 @@ our $class_messages = {
     'not_allowed'     => '[_1] not allowed',
     'error_occurred'  => 'error occurred',
     'required'        => '[_1] field is required',
+    'unique'          => 'Duplicate value for [_1]',
 };
 
 sub get_class_messages  {
@@ -677,6 +678,8 @@ sub get_class_messages  {
     my $messages = { %$class_messages };
     $messages->{required} = $self->required_message
         if $self->required_message;
+    $messages->{unique} = $self->unique_message
+        if $self->unique_message;
     return $messages;
 }
 
@@ -996,7 +999,7 @@ HTML::FormHandler::Field - base class for fields
 
 =head1 VERSION
 
-version 0.40026
+version 0.40027
 
 =head1 SYNOPSIS
 
